@@ -229,6 +229,9 @@ class ContentExtractor(object):
              'content': 'datetime'},
             {'attribute': 'name', 'value': 'publish_date',
              'content': 'content'},
+            # https://www.bangkokpost.com/world/711600/myawaddy-industrial-zone-set-for-2017-opening
+            {'attribute': 'name', 'value': 'cXenseParse:recs:publishtime',
+             'content': 'content'},
         ]
         for known_meta_tag in PUBLISH_DATE_TAGS:
             meta_tags = self.parser.get_elements_by_tag(
@@ -386,24 +389,6 @@ class ContentExtractor(object):
         title = title_pieces[large_text_index]
         return TITLE_REPLACEMENTS.replaceAll(title).strip()
 
-    def get_feed_urls(self, source_url, categories):
-        """Takes a source url and a list of category objects and returns
-        a list of feed urls
-        """
-        total_feed_urls = []
-        for category in categories:
-            kwargs = {'attr': 'type', 'value': 'application/rss+xml'}
-            feed_elements = self.parser.get_elements_by_tag(
-                category.doc, **kwargs)
-            feed_urls = [e.get('href') for e in feed_elements if e.get('href')]
-            total_feed_urls.extend(feed_urls)
-
-        total_feed_urls = total_feed_urls[:50]
-        total_feed_urls = [urls.prepare_url(f, source_url)
-                           for f in total_feed_urls]
-        total_feed_urls = list(set(total_feed_urls))
-        return total_feed_urls
-
     def get_favicon(self, doc):
         """Extract the favicon from a website http://en.wikipedia.org/wiki/Favicon
         <link rel="shortcut icon" type="image/png" href="favicon.png" />
@@ -642,125 +627,6 @@ class ContentExtractor(object):
             doc = doc_or_html
         return self._get_urls(doc, titles)
 
-    def get_category_urls(self, source_url, doc):
-        """Inputs source lxml root and source url, extracts domain and
-        finds all of the top level urls, we are assuming that these are
-        the category urls.
-        cnn.com --> [cnn.com/latest, world.cnn.com, cnn.com/asia]
-        """
-        page_urls = self.get_urls(doc)
-        valid_categories = []
-        for p_url in page_urls:
-            scheme = urls.get_scheme(p_url, allow_fragments=False)
-            domain = urls.get_domain(p_url, allow_fragments=False)
-            path = urls.get_path(p_url, allow_fragments=False)
-
-            if not domain and not path:
-                if self.config.verbose:
-                    log.debug('elim category url %s for no domain and path' % p_url)
-                continue
-            if path and path.startswith('#'):
-                if self.config.verbose:
-                    log.debug('elim category url %s path starts with #' % p_url)
-                continue
-            if scheme and (scheme != 'http' and scheme != 'https'):
-                if self.config.verbose:
-                    log.debug(('elim category url %s for bad scheme, not http nor https' % p_url))
-                continue
-
-            if domain:
-                child_tld = tldextract.extract(p_url)
-                domain_tld = tldextract.extract(source_url)
-                child_subdomain_parts = child_tld.subdomain.split('.')
-                subdomain_contains = False
-                for part in child_subdomain_parts:
-                    if part == domain_tld.domain:
-                        if self.config.verbose:
-                            log.debug(('subdomain contains at %s and %s' % (str(part), str(domain_tld.domain))))
-                        subdomain_contains = True
-                        break
-
-                # Ex. microsoft.com is definitely not related to
-                # espn.com, but espn.go.com is probably related to espn.com
-                if not subdomain_contains and \
-                        (child_tld.domain != domain_tld.domain):
-                    if self.config.verbose:
-                        log.debug(('elim category url %s for domain mismatch' % p_url))
-                        continue
-                elif child_tld.subdomain in ['m', 'i']:
-                    if self.config.verbose:
-                        log.debug(('elim category url %s for mobile subdomain' % p_url))
-                    continue
-                else:
-                    valid_categories.append(scheme + '://' + domain)
-                    # TODO account for case where category is in form
-                    # http://subdomain.domain.tld/category/ <-- still legal!
-            else:
-                # we want a path with just one subdir
-                # cnn.com/world and cnn.com/world/ are both valid_categories
-                path_chunks = [x for x in path.split('/') if len(x) > 0]
-                if 'index.html' in path_chunks:
-                    path_chunks.remove('index.html')
-
-                if len(path_chunks) == 1 and len(path_chunks[0]) < 14:
-                    valid_categories.append(domain + path)
-                else:
-                    if self.config.verbose:
-                        log.debug(('elim category url %s for >1 path chunks or size path chunks' % p_url))
-        ignore_category_urls = [
-            'about', 'help', 'privacy', 'legal', 'feedback', 'sitemap',
-            'profile', 'account', 'mobile', 'sitemap', 'facebook', 'myspace',
-            'twitter', 'linkedin', 'bebo', 'friendster', 'stumbleupon',
-            'youtube', 'vimeo', 'store', 'mail', 'preferences', 'maps',
-            'password', 'imgur', 'flickr', 'search', 'subscription', 'itunes',
-            'siteindex', 'events', 'stop', 'jobs', 'careers', 'newsletter',
-            'subscribe', 'academy', 'shopping', 'purchase', 'site-map',
-            'shop', 'donate', 'newsletter', 'product', 'advert', 'info',
-            'tickets', 'coupons', 'forum', 'board', 'archive', 'browse',
-            'howto', 'how to', 'faq', 'terms', 'charts', 'services',
-            'contact', 'plus', 'admin', 'login', 'signup', 'register',
-            'developer', 'proxy'
-        ]
-
-        # TODO Stop spamming urlparse and tldextract calls...
-        _valid_categories = []
-        for p_url in valid_categories:
-            path = urls.get_path(p_url)
-            subdomain = tldextract.extract(p_url).subdomain
-            conjunction = path + ' ' + subdomain
-            bad = False
-            for ignore_category_url in ignore_category_urls:
-                if ignore_category_url.lower() in conjunction.lower():
-                    if self.config.verbose:
-                        log.debug(('elim category url %s for subdomain contains stopword!' % p_url))
-                    bad = True
-                    break
-            if not bad:
-                _valid_categories.append(p_url)
-
-        _valid_categories.append('/')  # add the root
-
-        for i, p_url in enumerate(_valid_categories):
-            if p_url.startswith('://'):
-                p_url = 'http' + p_url
-                _valid_categories[i] = p_url
-
-            elif p_url.startswith('//'):
-                p_url = 'http:' + p_url
-                _valid_categories[i] = p_url
-
-            if p_url.endswith('/'):
-                p_url = p_url[:-1]
-                _valid_categories[i] = p_url
-
-        _valid_categories = list(set(_valid_categories))
-
-        category_urls = [urls.prepare_url(p_url, source_url)
-                         for p_url in _valid_categories]
-        category_urls = [c for c in category_urls if c is not None]
-        # remove duplicates from list!
-        return list(dict.fromkeys(category_urls))
-
     def extract_tags(self, doc):
         if len(list(doc)) == 0:
             return NO_STRINGS
